Learn R Programming

DVHmetrics (version 0.4.2)

DVHmetrics-package: Analyze Dose-Volume Histograms and Check Constraints

Description

Functionality for analyzing dose-volume histograms (DVH) in radiation oncology: Read DVH text files, calculate DVH metrics, gEUD, BED, EQD2, NTCP, TCP, show DVH diagrams, check and visualize quality assurance constraints for the DVH. Includes web-based graphical user interface.

Arguments

Author

Daniel Wollschlaeger and Heiko Karle

Maintainer: Daniel Wollschlaeger <wollschlaeger@uni-mainz.de>

Details

Package:DVHmetrics
Type:Package
Version:0.4.2
Date:2022-03-23
License:GPL (>= 2)

References

For a solution that also reads files in DICOM-RT format, see the RadOnc package: https://CRAN.R-project.org/package=RadOnc.

Examples

Run this code
showDVH(dataMZ[[1]])
checkConstraint(dataMZ, "D1CC < 10Gy")

Run the code above in your browser using DataLab