getDMEAN(x, interp=c("linear", "spline", "ksmooth", "smoothSpl"),
nodes=5001L)
## S3 method for class 'DVHs':
getDMEAN(x, interp=c("linear", "spline", "ksmooth", "smoothSpl"),
nodes=5001L)
## S3 method for class 'DVHLst':
getDMEAN(x, interp=c("linear", "spline", "ksmooth", "smoothSpl"),
nodes=5001L)
## S3 method for class 'DVHLstLst':
getDMEAN(x, interp=c("linear", "spline", "ksmooth", "smoothSpl"),
nodes=5001L)DVHs, multiple DVHs from one patient with multiple structures (object of class DVHLst), or multiple DVHs from many patients, each with multiple structures (object of class DVHLstLst). See numeric. Minimum number of nodes to use in interpolation for method "ksmooth". Number of available nodes is kept as is for NULL or if larger than nodes.getMetric,
approxfun,
splinefun,
smooth.spline,
dpill,
locpolygetDMEAN(dataMZ[[1]], interp="linear")Run the code above in your browser using DataLab