readDVH(x, type=c("Eclipse", "Cadplan", "Masterplan", "Pinnacle"),
planInfo=FALSE, add)character vector giving paths to DVH text files. May contain globbing symbols understood by Sys.glob. If missing and in interactive mode, readDVH opens a file selector widget.character string. Indicates which program the DVH text files were exported from. Supported: "Cadplan" (tested with version 6.4.7), "Eclipse" (tested with versions 10-13), "Masterplan" (tested with versioFALSE or character string. In the latter case, readDVH tries to extract additional information from the Plan field in the DVH file, e.g., the prescription dose for a sum plan or the DVHLstLst object. Existing object that should be merged with the new data from the files.DVHLstLst. This is a list (one component with class DVHLst for each original file from one patient) of lists (each component is an object of class DVHs). A DVHs object is a list with the following components:
[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object]Data:
Info.csv(variables"Filename","RegionOfInterestName","DoseMin cGy","DoseMax cGy","DoseMean cGy","Volume ccm")Info.csv variable "Filename". They should look like
DoseInfo.csv(variables"PrescriptionDose cGy","NumberOfFractions","Dosis cGy")PatInfo.csv(variables"LastName","FirstName","MedicalRecordNumber")PlanInfo.csv (variable "PlanName")Sys.glob,
print.DVHs,
showDVH,
getMetric,
checkConstraint# pick DVH files interactively
res <- readDVH()
res
# read all txt files in subdirectory DVH
res <- readDVH("DVH/*.txt", type="Eclipse")
resRun the code above in your browser using DataLab